pub enum Fork {
Resource,
Data,
}Expand description
Identifies either of the two forks that can be used to store data on classic Macintosh file systems
Variants
Resource
Identifies the resource fork that stores data in a system defined structure
Data
Identifies the data fork whose format is entirely up to the application creating it
Implementations