Module error

Module error 

Enums

ChecksumLocation
Error
Common error for working with the sit crate
ExtractionError
Error when trying to extract a specifc item form the archive
InvalidFileReason
Reasons why files can be ruled out as valid StuffIt archives
UnsupportedFeature
Archive features that are known to exist but are not implemented yet