Module structs
sit
0.3.0
Module structs
Module Items
Modules
Enums
In crate sit
sit
Module
structs
Data structures that make up the structure of archives
Modules

v1
Structures used in archive version from the early days until 4.5
v5
Structures used in StuffIt 5.0 and onwards
Enums

Algorithm
Archive
Header
Directory
Entry
File
Version
Version of an archive file