pub struct ArchiveHeader {
pub file_code: FourCC,
pub entry_count: u16,
pub archive_len: u32,
pub version: Version,
pub reserved: [u8; 7],
}Fields
file_code: FourCCFile identifier, this should be ‘SIT!’, ‘SITD’, ‘SIT2’ or ‘SIT5’.
If it says ‘Stuf’ you are probably dealing with a version 5 archive instead
entry_count: u16Number of entries in the root of the archive
archive_len: u32total size of the archive file in bytes (including header and everything)
version: VersionFile format (sub-)version
reserved: [u8; 7]Reserved for future use (in v1)
- if
version==1this is set to 00 00 00 00 00 00 00 - if
version==2this is set to XX NN NN NN NN XX XX where NN NN NN NN is the offset to the first root entry from the start of the file in bytes
Implementations
Sourceimpl ArchiveHeader
impl ArchiveHeader
pub fn first_entry_offset(&self) -> u64