pub struct File {Show 20 fields
pub rsrc_encrypted: bool,
pub rsrc_compression: Algorithm,
pub data_encrypted: bool,
pub data_compression: Algorithm,
pub file_name: String,
pub file_code: FourCC,
pub creator_code: FourCC,
pub flags: FinderFlags,
pub created_at: DateTime<Utc>,
pub modified_at: DateTime<Utc>,
pub rsrc_uncompressed_size: u32,
pub data_uncompressed_size: u32,
pub rsrc_compressed_size: u32,
pub data_compressed_size: u32,
pub rsrc_crc: u16,
pub data_crc: u16,
pub reserved: [u8; 6],
pub header_crc: u16,
pub payload_offset: u64,
pub index: usize,
}Fields
rsrc_encrypted: boolrsrc_compression: Algorithmdata_encrypted: booldata_compression: Algorithmfile_name: StringName of the compressed file
file_code: FourCCMac OS file type
creator_code: FourCCMac OS file creator
flags: FinderFlagsAttributes for file in Finder
created_at: DateTime<Utc>Creation date in classic Mac OS format (seconds since 1904)
modified_at: DateTime<Utc>Modification date in classic Mac OS format (seconds since 1904)
rsrc_uncompressed_size: u32Size of resource fork after decompression
data_uncompressed_size: u32Size of data fork after decompression
rsrc_compressed_size: u32Size of compressed resource fork data
data_compressed_size: u32Size of compressed data fork data
rsrc_crc: u16CRC-16 checksum for decompressed resource data
The CRC-16 configuration is CRC-16-IBM also known as CRC-16-ARC where the CRC of ASCII “123456789” is 0xbb3d.
data_crc: u16CRC-16 checksum for decompressed data fork data
The CRC-16 configuration is CRC-16-IBM also known as CRC-16-ARC where the CRC of ASCII “123456789” is 0xbb3d.
reserved: [u8; 6]Reserved for future use
header_crc: u16CRC-16 checksum of the file header without these last two bytes
The CRC-16 configuration is CRC-16-IBM also known as CRC-16-ARC where the CRC of ASCII “123456789” is 0xbb3d.
payload_offset: u64index: usizeIndex of the file entry determine by counting previous file entries in depth-first search order
Implementations
Sourceimpl File
impl File
pub fn uncompressed_size(&self, fork: Fork) -> usize
pub fn compressed_size(&self, fork: Fork) -> usize
pub fn compression_method(&self, fork: Fork) -> Algorithm
pub fn checksum(&self, fork: Fork) -> u16
pub fn encrypted(&self, fork: Fork) -> bool
pub fn offset(&self, fork: Fork) -> u64
pub fn uses_encryption(&self) -> bool